pub(crate) struct ConfirmLeaveRoomResponse {
pub ignore_inviter: bool,
}Expand description
A response to the dialog to confirm leaving a room
Fields
ignore_inviter: boolIf the room is an invite, whether the user wants to ignore the inviter.